@@ -6,20 +6,20 @@
 #'
 #' @importFrom stats ks.test
 #' @import BiocParallel
-#' @import futile.logger
+#' @import logger
 #'
 #' @return the medians p-values for genes in a batch
 calcBatchEffectsForBatch <- function(batch, samples, data, 
                                      BPPARAM = SerialParam()) {
-  flog.debug(paste("Calculating the batch effect for batch", batch))
+  log_debug(paste("Calculating the batch effect for batch", batch))
 
-  flog.debug("Subsetting data.table for batch")
+  log_debug("Subsetting data.table for batch")
   DT_batch <- samples[batch_id == batch][data
     , ,
     on = .(sample_id = sample),
     nomatch = 0
   ][, .(feature, beta.value)]
-  flog.debug("Subsetting data.table for others")
+  log_debug("Subsetting data.table for others")
   DT_other <- samples[batch_id != batch][data
     , ,
     on = .(sample_id = sample),
@@ -30,7 +30,7 @@ calcBatchEffectsForBatch <- function(batch, samples, data,
   features_batch <- DT_batch[, list(list(beta.value)), by = feature]$V1
   features_other <- DT_other[, list(list(beta.value)), by = feature]$V1
 
-  flog.debug(paste("Calculating the p-values for batch", batch))
+  log_debug(paste("Calculating the p-values for batch", batch))
   result <- bpmapply(function(X, Y) {
     medianDiff <- median(X, na.rm = TRUE) - median(Y, na.rm = TRUE)
     if (all(is.na(X))) {
